@@ -122,7 +122,7 @@ reconstruct_pattern <- function(pattern, method = "homo",
     if (simplify) {
 
       # not possible if more than one pattern is present
-      if (n_random > 1 && verbose) {
+      if (n_random > 1) {
 
         warning("'simplify = TRUE' not possible for 'n_random > 1'.",
                 call. = FALSE)
@@ -139,7 +139,7 @@ reconstruct_pattern <- function(pattern, method = "homo",
   } else {
 
     # return warning if simply = TRUE because not possible if return_input = TRUE (only verbose = TRUE)
-    if (simplify && verbose) {
+    if (simplify) {
 
       warning("'simplify = TRUE' not possible for 'return_input = TRUE'.", call. = FALSE)
 
