@@ -55,14 +55,11 @@ translate_raster <- function(raster, steps_x = NULL, steps_y = NULL,
   habitats <- sort(table(terra::values(raster, mat = FALSE))) # get table of habitats
 
   # print warning if more than 10 classes are present
-  if (verbose) {
+  if (length(habitats) > 10) {
 
-    if (length(habitats) > 10) {
+    warning("The raster has more than 10 classes. Please make sure discrete classes are provided.",
+            call. = FALSE)
 
-      warning("The raster has more than 10 classes. Please make sure discrete classes are provided.",
-              call. = FALSE)
-
-    }
   }
 
   # use all possible combinations
@@ -171,7 +168,7 @@ translate_raster <- function(raster, steps_x = NULL, steps_y = NULL,
     if (simplify) {
 
       # not possible if more than one raster is present
-      if (n_random > 1 && verbose) {
+      if (n_random > 1) {
 
         warning("'simplify = TRUE' not possible for 'n_random > 1'.",
                 call. = FALSE)
@@ -189,7 +186,7 @@ translate_raster <- function(raster, steps_x = NULL, steps_y = NULL,
   else {
 
     # return warning if simply = TRUE because not possible if return_input = TRUE (only verbose = TRUE)
-    if (simplify && verbose) {
+    if (simplify) {
 
       warning("'simplify = TRUE' not possible for 'return_input = TRUE'.", call. = FALSE)
 
