@@ -13,9 +13,6 @@ raster_random_ni <- translate_raster(raster = landscape_classified,
                                      steps_x = 1:1, steps_y = 1:1,
                                      return_input = FALSE, verbose = FALSE)
 
-raster_random_cont <- translate_raster(raster = terra::rast(landscape),
-                                       steps_x = 1:1, steps_y = 1:1, verbose = FALSE)
-
 ################################################################################
 
 testthat::test_that("plot returns plot", {
@@ -45,9 +42,3 @@ testthat::test_that("plot returns error if wrong id are selected ", {
   testthat::expect_error(plot(raster_random, n = c(100, 101, 102), verbose = FALSE),
                          regexp = "Please provide at least on valid ID for n.")
 })
-
-testthat::test_that("plot returns warning if more than 10 classes are present", {
-
-  testthat::expect_warning(plot(raster_random_cont),
-                           regexp = "The raster has more than 10 classes. Please make sure discrete classes are provided.")
-})
